@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 import numpy as np
+
 # from scipy.interpolate import interp1d, interp2d
 import re
 
@@ -19,6 +20,7 @@ from ..core.quant_analysis import ParamQuantitativeAnalysis
 from ..core.xrf_utils import check_if_eline_supported
 
 import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -63,6 +65,7 @@ class DrawImageAdvanced(Atom):
     limit_dict : Dict
         save low and high limit for image scaling
     """
+
     # Reference to FileIOMOdel
     io_model = Typed(object)
 
@@ -72,8 +75,8 @@ class DrawImageAdvanced(Atom):
     dict_to_plot = Dict()
     items_previous_selected = List()
 
-    scale_opt = Str('Linear')
-    color_opt = Str('viridis')
+    scale_opt = Str("Linear")
+    color_opt = Str("viridis")
     img_title = Str()
 
     scaler_norm_dict = Dict()
@@ -118,11 +121,21 @@ class DrawImageAdvanced(Atom):
         self.io_model = io_model
 
         self.fig = plt.figure(figsize=(3, 2))
-        matplotlib.rcParams['axes.formatter.useoffset'] = True
+        matplotlib.rcParams["axes.formatter.useoffset"] = True
 
         # Do not apply scaler norm on following data
-        self.name_not_scalable = ['r2_adjust', 'r_factor', 'alive', 'dead', 'elapsed_time',
-                                  'scaler_alive', 'i0_time', 'time', 'time_diff', 'dwell_time']
+        self.name_not_scalable = [
+            "r2_adjust",
+            "r_factor",
+            "alive",
+            "dead",
+            "elapsed_time",
+            "scaler_alive",
+            "i0_time",
+            "time",
+            "time_diff",
+            "dwell_time",
+        ]
 
         self.param_quant_analysis = ParamQuantitativeAnalysis()
         self.param_quant_analysis.set_experiment_distance_to_sample(distance_to_sample=0.0)
@@ -138,7 +151,7 @@ class DrawImageAdvanced(Atom):
         changed : bool
             True - 'io_model.img_dict` was updated, False - ignore
         """
-        if change['value']:
+        if change["value"]:
             self.select_dataset(self.io_model.img_dict_default_selected_item)
             self.init_plot_status()
 
@@ -146,7 +159,7 @@ class DrawImageAdvanced(Atom):
         # init of scaler for normalization
         self.scaler_name_index = 0
 
-        scaler_groups = [v for v in list(self.io_model.img_dict.keys()) if 'scaler' in v]
+        scaler_groups = [v for v in list(self.io_model.img_dict.keys()) if "scaler" in v]
         if len(scaler_groups) > 0:
             # self.scaler_group_name = scaler_groups[0]
             self.scaler_norm_dict = self.io_model.img_dict[scaler_groups[0]]
@@ -159,11 +172,11 @@ class DrawImageAdvanced(Atom):
         # init of pos values
         self.set_pixel_or_pos(0)
 
-        if 'positions' in self.io_model.img_dict:
+        if "positions" in self.io_model.img_dict:
             try:
                 logger.debug(f"Position keys: {list(self.io_model.img_dict['positions'].keys())}")
-                self.x_pos = list(self.io_model.img_dict['positions']['x_pos'][0, :])
-                self.y_pos = list(self.io_model.img_dict['positions']['y_pos'][:, -1])
+                self.x_pos = list(self.io_model.img_dict["positions"]["x_pos"][0, :])
+                self.y_pos = list(self.io_model.img_dict["positions"]["y_pos"][:, -1])
                 # when we use imshow, the x and y start at lower left,
                 # so flip y, we want y starts from top left
                 self.y_pos.reverse()
@@ -174,15 +187,15 @@ class DrawImageAdvanced(Atom):
             self.x_pos = []
             self.y_pos = []
 
-        logger.info('Use previously selected items as default: {}'.format(self.items_previous_selected))
-        logger.debug('The following groups are included for 2D image display: {}'.
-                     format(self.io_model.img_dict_keys))
+        logger.info("Use previously selected items as default: {}".format(self.items_previous_selected))
+        logger.debug(
+            "The following groups are included for 2D image display: {}".format(self.io_model.img_dict_keys)
+        )
 
         self.show_image()
 
     def reset_to_default(self):
-        """Set variables to default values as initiated.
-        """
+        """Set variables to default values as initiated."""
         self.select_dataset(0)
         # init of scaler for normalization
         self.set_scaler_index(0)
@@ -195,7 +208,7 @@ class DrawImageAdvanced(Atom):
         if img_title:
             if re.search(r"_det\d+_fit$", img_title):
                 s = re.search(r"_det\d+_", img_title)[0]
-                return s.strip('_')
+                return s.strip("_")
             if re.search(r"_fit", img_title):
                 return "sum"
         else:
@@ -215,8 +228,9 @@ class DrawImageAdvanced(Atom):
         plot_item = self._get_current_plot_item()
         keys_unsorted = list(self.io_model.img_dict[plot_item].keys())
         if len(keys_unsorted) != len(set(keys_unsorted)):
-            logger.warning("DrawImageAdvanced:set_map_keys(): repeated keys "
-                           f"in the dictionary 'img_dict': {keys_unsorted}")
+            logger.warning(
+                f"DrawImageAdvanced:set_map_keys(): repeated keys in the dictionary 'img_dict': {keys_unsorted}"
+            )
         keys_elines, keys_scalers = [], []
         for key in keys_unsorted:
             if check_if_eline_supported(key):  # Check if 'key' is an emission line (such as "Ca_K")
@@ -244,7 +258,7 @@ class DrawImageAdvanced(Atom):
                 self.dict_to_plot = {}
                 self.map_keys.clear()
                 self.set_stat_for_all(bool_val=False)
-                self.img_title = ''
+                self.img_title = ""
             elif self.data_opt > 0:
                 # self.set_stat_for_all(bool_val=False)
                 plot_item = self._get_current_plot_item()
@@ -280,16 +294,18 @@ class DrawImageAdvanced(Atom):
             self.scaler_data = None
         else:
             try:
-                scaler_name = self.scaler_items[self.scaler_name_index-1]
+                scaler_name = self.scaler_items[self.scaler_name_index - 1]
             except IndexError:
                 scaler_name = None
             if scaler_name:
                 self.scaler_data = self.scaler_norm_dict[scaler_name]
-                logger.info('Use scaler data to normalize, '
-                            'and the shape of scaler data is {}, '
-                            'with (low, high) as ({}, {})'.format(self.scaler_data.shape,
-                                                                  np.min(self.scaler_data),
-                                                                  np.max(self.scaler_data)))
+                logger.info(
+                    "Use scaler data to normalize, "
+                    "and the shape of scaler data is {}, "
+                    "with (low, high) as ({}, {})".format(
+                        self.scaler_data.shape, np.min(self.scaler_data), np.max(self.scaler_data)
+                    )
+                )
         self.set_low_high_value()  # reset low high values based on normalization
         self.show_image()
 
@@ -346,8 +362,7 @@ class DrawImageAdvanced(Atom):
             self.scale_opt = scale_opt
             self.show_image()
         else:
-            logger.error(f"XRF Maps: 'scale_opt' has illegal value: {scale_opt}. "
-                         f"Allowed values: {scale_opt_list}")
+            logger.error(f"XRF Maps: 'scale_opt' has illegal value: {scale_opt}. Allowed values: {scale_opt_list}")
 
     def set_color_opt(self, color_opt):
         self.color_opt = color_opt
@@ -385,7 +400,7 @@ class DrawImageAdvanced(Atom):
         self.scatter_show = is_scatter
         self.show_image()
 
-    @observe('quant_distance_to_sample')
+    @observe("quant_distance_to_sample")
     def _on_change_distance_to_sample(self, change):
         # Set the value of the quantitative analysis parameter
         self.param_quant_analysis.set_experiment_distance_to_sample(self.quant_distance_to_sample)
@@ -405,7 +420,7 @@ class DrawImageAdvanced(Atom):
         """
         self.incident_energy = change["value"]
 
-    @observe('incident_energy')
+    @observe("incident_energy")
     def _on_change_incident_energy(self, change):
         self.param_quant_analysis.set_experiment_incident_energy(incident_energy=self.incident_energy)
 
@@ -418,13 +433,12 @@ class DrawImageAdvanced(Atom):
         self.stat_dict = {k: bool_val for k in self.map_keys}
 
         self.limit_dict.clear()
-        self.limit_dict = {k: {'low': 0.0, 'high': 100.0} for k in self.map_keys}
+        self.limit_dict = {k: {"low": 0.0, "high": 100.0} for k in self.map_keys}
 
         self.set_low_high_value()
 
     def set_low_high_value(self):
-        """Set default low and high values based on normalization for each image.
-        """
+        """Set default low and high values based on normalization for each image."""
         # do not apply scaler norm on not scalable data
         self.range_dict.clear()
 
@@ -437,29 +451,30 @@ class DrawImageAdvanced(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=data_name,
-                    name_not_scalable=self.name_not_scalable)
+                    name_not_scalable=self.name_not_scalable,
+                )
             else:
                 # Normalize by the selected scaler in a regular way
-                data_arr = normalize_data_by_scaler(data_in=self.dict_to_plot[data_name],
-                                                    scaler=self.scaler_data,
-                                                    data_name=data_name,
-                                                    name_not_scalable=self.name_not_scalable)
+                data_arr = normalize_data_by_scaler(
+                    data_in=self.dict_to_plot[data_name],
+                    scaler=self.scaler_data,
+                    data_name=data_name,
+                    name_not_scalable=self.name_not_scalable,
+                )
 
             lowv, highv = np.min(data_arr), np.max(data_arr)
             # Create some 'artificially' small range in case the array is constant
             if lowv == highv:
                 lowv -= 0.005
                 highv += 0.005
-            self.range_dict[data_name] = {'low': lowv, 'low_default': lowv,
-                                          'high': highv, 'high_default': highv}
+            self.range_dict[data_name] = {"low": lowv, "low_default": lowv, "high": highv, "high_default": highv}
 
     def reset_low_high(self, name):
-        """Reset low and high value to default based on normalization.
-        """
-        self.range_dict[name]['low'] = self.range_dict[name]['low_default']
-        self.range_dict[name]['high'] = self.range_dict[name]['high_default']
-        self.limit_dict[name]['low'] = 0.0
-        self.limit_dict[name]['high'] = 100.0
+        """Reset low and high value to default based on normalization."""
+        self.range_dict[name]["low"] = self.range_dict[name]["low_default"]
+        self.range_dict[name]["high"] = self.range_dict[name]["high_default"]
+        self.limit_dict[name]["low"] = 0.0
+        self.limit_dict[name]["high"] = 100.0
         self.show_image()
 
     def show_image(self):
@@ -477,7 +492,7 @@ class DrawImageAdvanced(Atom):
         # While the data from the completed part of experiment may still be used,
         # plotting vs. x-y or scatter plot may not be displayed.
         positions_data_available = False
-        if 'positions' in self.io_model.img_dict.keys():
+        if "positions" in self.io_model.img_dict.keys():
             positions_data_available = True
 
         # Create local copies of self.pixel_or_pos, self.scatter_show and self.grid_interpolate
@@ -498,19 +513,19 @@ class DrawImageAdvanced(Atom):
                 logger.error("'Positions' data is not available. Interpolation is disabled.")
 
         rel_low_lim = 1e-6  # define the relative low limit for log image
-        plot_interp = 'Nearest'
+        plot_interp = "Nearest"
 
         if self.scaler_data is not None:
             if np.count_nonzero(self.scaler_data) == 0:
-                logger.warning('scaler is zero - scaling was not applied')
+                logger.warning("scaler is zero - scaling was not applied")
             elif len(self.scaler_data[self.scaler_data == 0]) > 0:
-                logger.warning('scaler data has zero values')
+                logger.warning("scaler data has zero values")
 
         grey_use = self.color_opt
 
         ncol = int(np.ceil(np.sqrt(len(selected_keys))))
         try:
-            nrow = int(np.ceil(len(selected_keys)/float(ncol)))
+            nrow = int(np.ceil(len(selected_keys) / float(ncol)))
         except ZeroDivisionError:
             ncol = 1
             nrow = 1
@@ -518,14 +533,17 @@ class DrawImageAdvanced(Atom):
         a_pad_v = 0.8
         a_pad_h = 0.5
 
-        grid = ImageGrid(self.fig, 111,
-                         nrows_ncols=(nrow, ncol),
-                         axes_pad=(a_pad_v, a_pad_h),
-                         cbar_location='right',
-                         cbar_mode='each',
-                         cbar_size='7%',
-                         cbar_pad='2%',
-                         share_all=True)
+        grid = ImageGrid(
+            self.fig,
+            111,
+            nrows_ncols=(nrow, ncol),
+            axes_pad=(a_pad_v, a_pad_h),
+            cbar_location="right",
+            cbar_mode="each",
+            cbar_size="7%",
+            cbar_pad="2%",
+            share_all=True,
+        )
 
         def _compute_equal_axes_ranges(x_min, x_max, y_min, y_max):
             """
@@ -605,23 +623,27 @@ class DrawImageAdvanced(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=k,
-                    name_not_scalable=self.name_not_scalable)
+                    name_not_scalable=self.name_not_scalable,
+                )
             else:
                 # Normalize by the selected scaler in a regular way
-                data_arr = normalize_data_by_scaler(data_in=self.dict_to_plot[k],
-                                                    scaler=self.scaler_data,
-                                                    data_name=k,
-                                                    name_not_scalable=self.name_not_scalable)
+                data_arr = normalize_data_by_scaler(
+                    data_in=self.dict_to_plot[k],
+                    scaler=self.scaler_data,
+                    data_name=k,
+                    name_not_scalable=self.name_not_scalable,
+                )
 
             if pixel_or_pos_local or scatter_show_local:
 
                 # xd_min, xd_max, yd_min, yd_max = min(self.x_pos), max(self.x_pos),
                 #     min(self.y_pos), max(self.y_pos)
-                x_pos_2D = self.io_model.img_dict['positions']['x_pos']
-                y_pos_2D = self.io_model.img_dict['positions']['y_pos']
+                x_pos_2D = self.io_model.img_dict["positions"]["x_pos"]
+                y_pos_2D = self.io_model.img_dict["positions"]["y_pos"]
                 xd_min, xd_max, yd_min, yd_max = x_pos_2D.min(), x_pos_2D.max(), y_pos_2D.min(), y_pos_2D.max()
-                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = \
-                    _compute_equal_axes_ranges(xd_min, xd_max, yd_min, yd_max)
+                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = _compute_equal_axes_ranges(
+                    xd_min, xd_max, yd_min, yd_max
+                )
 
                 xd_min, xd_max = _adjust_data_range_using_min_ratio(xd_min, xd_max, xd_axis_max - xd_axis_min)
                 yd_min, yd_max = _adjust_data_range_using_min_ratio(yd_min, yd_max, yd_axis_max - yd_axis_min)
@@ -643,21 +665,22 @@ class DrawImageAdvanced(Atom):
                 if (xd <= math.floor(yd / 100)) and (yd >= 200):
                     xd_min, xd_max = -math.floor(yd / 200), math.ceil(yd / 200)
 
-                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = \
-                    _compute_equal_axes_ranges(xd_min, xd_max, yd_min, yd_max)
+                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = _compute_equal_axes_ranges(
+                    xd_min, xd_max, yd_min, yd_max
+                )
 
             # Compute limits (used both for linear and log plots
-            low_ratio = self.limit_dict[k]['low']/100.0
-            high_ratio = self.limit_dict[k]['high']/100.0
+            low_ratio = self.limit_dict[k]["low"] / 100.0
+            high_ratio = self.limit_dict[k]["high"] / 100.0
             if (self.scaler_data is None) and (not quant_norm_applied):
-                minv = self.range_dict[k]['low']
-                maxv = self.range_dict[k]['high']
+                minv = self.range_dict[k]["low"]
+                maxv = self.range_dict[k]["high"]
             else:
                 # Unfortunately, the new normalization procedure requires to recalculate min and max values
                 minv = np.min(data_arr)
                 maxv = np.max(data_arr)
-            low_limit = (maxv-minv)*low_ratio + minv
-            high_limit = (maxv-minv)*high_ratio + minv
+            low_limit = (maxv - minv) * low_ratio + minv
+            high_limit = (maxv - minv) * high_ratio + minv
             # Set some minimum range for the colorbar (otherwise it will have white fill)
             if math.isclose(low_limit, high_limit, abs_tol=2e-20):
                 if abs(low_limit) < 1e-20:  # The value is zero
@@ -667,33 +690,44 @@ class DrawImageAdvanced(Atom):
                 high_limit += dv
                 low_limit -= dv
 
-            if self.scale_opt == 'Linear':
+            if self.scale_opt == "Linear":
 
                 if not scatter_show_local:
                     if grid_interpolate_local:
-                        data_arr, _, _ = grid_interpolate(data_arr,
-                                                          self.io_model.img_dict['positions']['x_pos'],
-                                                          self.io_model.img_dict['positions']['y_pos'])
-                    im = grid[i].imshow(data_arr,
-                                        cmap=grey_use,
-                                        interpolation=plot_interp,
-                                        extent=(xd_min, xd_max, yd_max, yd_min),
-                                        origin='upper',
-                                        clim=(low_limit, high_limit))
+                        data_arr, _, _ = grid_interpolate(
+                            data_arr,
+                            self.io_model.img_dict["positions"]["x_pos"],
+                            self.io_model.img_dict["positions"]["y_pos"],
+                        )
+                    im = grid[i].imshow(
+                        data_arr,
+                        cmap=grey_use,
+                        interpolation=plot_interp,
+                        extent=(xd_min, xd_max, yd_max, yd_min),
+                        origin="upper",
+                        clim=(low_limit, high_limit),
+                    )
                     grid[i].set_ylim(yd_axis_max, yd_axis_min)
                 else:
-                    xx = self.io_model.img_dict['positions']['x_pos']
-                    yy = self.io_model.img_dict['positions']['y_pos']
+                    xx = self.io_model.img_dict["positions"]["x_pos"]
+                    yy = self.io_model.img_dict["positions"]["y_pos"]
 
                     # The following condition prevents crash if different file is loaded while
                     #    the scatter plot is open (PyXRF specific issue)
                     if data_arr.shape == xx.shape and data_arr.shape == yy.shape:
-                        im = grid[i].scatter(xx, yy, c=data_arr,
-                                             marker='s', s=500,
-                                             alpha=1.0,  # Originally: alpha=0.8
-                                             cmap=grey_use,
-                                             vmin=low_limit, vmax=high_limit,
-                                             linewidths=1, linewidth=0)
+                        im = grid[i].scatter(
+                            xx,
+                            yy,
+                            c=data_arr,
+                            marker="s",
+                            s=500,
+                            alpha=1.0,  # Originally: alpha=0.8
+                            cmap=grey_use,
+                            vmin=low_limit,
+                            vmax=high_limit,
+                            linewidths=1,
+                            linewidth=0,
+                        )
                         grid[i].set_ylim(yd_axis_max, yd_axis_min)
 
                 grid[i].set_xlim(xd_axis_min, xd_axis_max)
@@ -701,14 +735,14 @@ class DrawImageAdvanced(Atom):
                 grid_title = k
                 if quant_norm_applied:
                     grid_title += " - Q"  # Mark the plots that represent quantitative information
-                grid[i].text(0, 1.01, grid_title, ha='left', va='bottom', transform=grid[i].axes.transAxes)
+                grid[i].text(0, 1.01, grid_title, ha="left", va="bottom", transform=grid[i].axes.transAxes)
 
                 grid.cbar_axes[i].colorbar(im)
                 im.colorbar.formatter = im.colorbar.ax.yaxis.get_major_formatter()
 
                 # im.colorbar.ax.get_xaxis().set_ticks([])
                 # im.colorbar.ax.get_xaxis().set_ticks([], minor=True)
-                grid.cbar_axes[i].ticklabel_format(style='sci', scilimits=(-3, 4), axis='both')
+                grid.cbar_axes[i].ticklabel_format(style="sci", scilimits=(-3, 4), axis="both")
 
                 #  Do not remove this code, may be useful in the future (Dmitri G.) !!!
                 #  Print label for colorbar
@@ -730,31 +764,39 @@ class DrawImageAdvanced(Atom):
 
                 if not scatter_show_local:
                     if grid_interpolate_local:
-                        data_arr, _, _ = grid_interpolate(data_arr,
-                                                          self.io_model.img_dict['positions']['x_pos'],
-                                                          self.io_model.img_dict['positions']['y_pos'])
-                    im = grid[i].imshow(data_arr,
-                                        # norm=LogNorm(vmin=low_lim*maxz,
-                                        #              vmax=maxz, clip=True),
-                                        norm=LogNorm(vmin=low_limit,
-                                                     vmax=high_limit, clip=True),
-                                        cmap=grey_use,
-                                        interpolation=plot_interp,
-                                        extent=(xd_min, xd_max, yd_max, yd_min),
-                                        origin='upper',
-                                        # clim=(low_lim*maxz, maxz))
-                                        clim=(low_limit, high_limit))
+                        data_arr, _, _ = grid_interpolate(
+                            data_arr,
+                            self.io_model.img_dict["positions"]["x_pos"],
+                            self.io_model.img_dict["positions"]["y_pos"],
+                        )
+                    im = grid[i].imshow(
+                        data_arr,
+                        # norm=LogNorm(vmin=low_lim*maxz,
+                        #              vmax=maxz, clip=True),
+                        norm=LogNorm(vmin=low_limit, vmax=high_limit, clip=True),
+                        cmap=grey_use,
+                        interpolation=plot_interp,
+                        extent=(xd_min, xd_max, yd_max, yd_min),
+                        origin="upper",
+                        # clim=(low_lim*maxz, maxz))
+                        clim=(low_limit, high_limit),
+                    )
                     grid[i].set_ylim(yd_axis_max, yd_axis_min)
                 else:
-                    im = grid[i].scatter(self.io_model.img_dict['positions']['x_pos'],
-                                         self.io_model.img_dict['positions']['y_pos'],
-                                         # norm=LogNorm(vmin=low_lim*maxz,
-                                         #              vmax=maxz, clip=True),
-                                         norm=LogNorm(vmin=low_limit,
-                                                      vmax=high_limit, clip=True),
-                                         c=data_arr, marker='s', s=500, alpha=1.0,  # Originally: alpha=0.8
-                                         cmap=grey_use,
-                                         linewidths=1, linewidth=0)
+                    im = grid[i].scatter(
+                        self.io_model.img_dict["positions"]["x_pos"],
+                        self.io_model.img_dict["positions"]["y_pos"],
+                        # norm=LogNorm(vmin=low_lim*maxz,
+                        #              vmax=maxz, clip=True),
+                        norm=LogNorm(vmin=low_limit, vmax=high_limit, clip=True),
+                        c=data_arr,
+                        marker="s",
+                        s=500,
+                        alpha=1.0,  # Originally: alpha=0.8
+                        cmap=grey_use,
+                        linewidths=1,
+                        linewidth=0,
+                    )
                     grid[i].set_ylim(yd_axis_min, yd_axis_max)
 
                 grid[i].set_xlim(xd_axis_min, xd_axis_max)
@@ -762,7 +804,7 @@ class DrawImageAdvanced(Atom):
                 grid_title = k
                 if quant_norm_applied:
                     grid_title += " - Q"  # Mark the plots that represent quantitative information
-                grid[i].text(0, 1.01, grid_title, ha='left', va='bottom', transform=grid[i].axes.transAxes)
+                grid[i].text(0, 1.01, grid_title, ha="left", va="bottom", transform=grid[i].axes.transAxes)
 
                 grid.cbar_axes[i].colorbar(im)
                 im.colorbar.formatter = im.colorbar.ax.yaxis.get_major_formatter()
@@ -781,8 +823,7 @@ class DrawImageAdvanced(Atom):
         self.fig.canvas.draw_idle()
 
     def get_selected_items_for_plot(self):
-        """Collect the selected items for plotting.
-        """
+        """Collect the selected items for plotting."""
         # We want the dictionary to be sorted the same way as 'map_keys'
         sdict = self.stat_dict
         selected_keys = [_ for _ in self.map_keys if (_ in sdict) and (sdict[_] is True)]
