@@ -159,6 +159,7 @@ class ScanMetadataXRF(ScanMetadataBase):
             "scan_uid",
             "scan_instrument_name",
             "scan_instrument_id",
+            "scan_end_station",
             "scan_time_start",
             "scan_time_start_utc",
             "scan_time_stop",
@@ -216,6 +217,7 @@ class ScanMetadataXRF(ScanMetadataBase):
             "scan_time_stop_utc": "stop time (UTC)",
             "scan_instrument_id": "beamline ID",
             "scan_instrument_name": "beamline name",
+            "scan_end_station": "end station",
             "scan_exit_status": "exit status",
             "instrument_mono_incident_energy": "incident energy",
             "instrument_beam_current": "ring current, mA",
